==> aws-sdk-cpp-1.11.647-1-x86_64.pkg.tar.zst: usr/include/aws/datazone/DataZoneEndpointProvider.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/datazone/DataZone_EXPORTS.h>
#include <aws/core/client/GenericClientConfiguration.h>
#include <aws/core/endpoint/DefaultEndpointProvider.h>
#include <aws/core/endpoint/EndpointParameter.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>

#include <aws/datazone/DataZoneEndpointRules.h>


namespace Aws
{
namespace DataZone
{
namespace Endpoint
{
using EndpointParameters = Aws::Endpoint::EndpointParameters;
using Aws::Endpoint::EndpointProviderBase;
using Aws::Endpoint::DefaultEndpointProvider;

using DataZoneClientContextParameters = Aws::Endpoint::ClientContextParameters;

using DataZoneClientConfiguration = Aws::Client::GenericClientConfiguration;
using DataZoneBuiltInParameters = Aws::Endpoint::BuiltInParameters;

/**
 * The type for the DataZone Client Endpoint Provider.
 * Inherit from this Base class / "Interface" should you want to provide a custom endpoint provider.
 * The SDK must use service-specific type for each service per specification.
 */
using DataZoneEndpointProviderBase =
    EndpointProviderBase<DataZoneClientConfiguration, DataZoneBuiltInParameters, DataZoneClientContextParameters>;

using DataZoneDefaultEpProviderBase =
    DefaultEndpointProvider<DataZoneClientConfiguration, DataZoneBuiltInParameters, DataZoneClientContextParameters>;

/**
 * Default endpoint provider used for this service
 */
class AWS_DATAZONE_API DataZoneEndpointProvider : public DataZoneDefaultEpProviderBase
{
public:
    using DataZoneResolveEndpointOutcome = Aws::Endpoint::ResolveEndpointOutcome;

    DataZoneEndpointProvider()
      : DataZoneDefaultEpProviderBase(Aws::DataZone::DataZoneEndpointRules::GetRulesBlob(), Aws::DataZone::DataZoneEndpointRules::RulesBlobSize)
    {}

    ~DataZoneEndpointProvider()
    {
    }
};
} // namespace Endpoint
} // namespace DataZone
} // namespace Aws

==> aws-sdk-cpp-1.11.710-1-x86_64.pkg.tar.zst: usr/include/aws/datazone/DataZoneEndpointProvider.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/client/GenericClientConfiguration.h>
#include <aws/core/endpoint/DefaultEndpointProvider.h>
#include <aws/core/endpoint/EndpointParameter.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <aws/datazone/DataZoneEndpointRules.h>
#include <aws/datazone/DataZone_EXPORTS.h>

namespace Aws {
namespace DataZone {
namespace Endpoint {
using EndpointParameters = Aws::Endpoint::EndpointParameters;
using Aws::Endpoint::DefaultEndpointProvider;
using Aws::Endpoint::EndpointProviderBase;

using DataZoneClientContextParameters = Aws::Endpoint::ClientContextParameters;

using DataZoneClientConfiguration = Aws::Client::GenericClientConfiguration;
using DataZoneBuiltInParameters = Aws::Endpoint::BuiltInParameters;

/**
 * The type for the DataZone Client Endpoint Provider.
 * Inherit from this Base class / "Interface" should you want to provide a custom endpoint provider.
 * The SDK must use service-specific type for each service per specification.
 */
using DataZoneEndpointProviderBase =
    EndpointProviderBase<DataZoneClientConfiguration, DataZoneBuiltInParameters, DataZoneClientContextParameters>;

using DataZoneDefaultEpProviderBase =
    DefaultEndpointProvider<DataZoneClientConfiguration, DataZoneBuiltInParameters, DataZoneClientContextParameters>;

/**
 * Default endpoint provider used for this service
 */
class AWS_DATAZONE_API DataZoneEndpointProvider : public DataZoneDefaultEpProviderBase {
 public:
  using DataZoneResolveEndpointOutcome = Aws::Endpoint::ResolveEndpointOutcome;

  DataZoneEndpointProvider()
      : DataZoneDefaultEpProviderBase(Aws::DataZone::DataZoneEndpointRules::GetRulesBlob(),
                                      Aws::DataZone::DataZoneEndpointRules::RulesBlobSize) {}

  ~DataZoneEndpointProvider() {}
};
}  // namespace Endpoint
}  // namespace DataZone
}  // namespace Aws
